==> lava-server_2016.4.orig.tar.gz: lava-server-2016.4/dashboard_app/management/commands/authorize_superuser.py <==
# Copyright (C) 2015 Linaro Limited
#
# Author: Senthil Kumaran S <senthil.kumaran@linaro.org>
#
# This file is part of LAVA Dashboard
#
# Lava Dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License version 3
# as published by the Free Software Foundation
#
# Lava Dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Lava Dashboard. If not, see <http://www.gnu.org/licenses/>.


import sys

from django.contrib.auth.models import User
from lava_server.utils import OptArgBaseCommand as BaseCommand


class Command(BaseCommand):
    help = 'Authorize superuser.'

    def add_arguments(self, parser):
        parser.add_argument('--username', type=str,
                            help='Username to authorize.')

    def handle(self, *args, **options):
        username = options['username']
        if username is None:
            self.stderr.write("Username not specified.")
            sys.exit(2)

        try:
            user = User.objects.get(username=username)
            user.is_staff = True
            user.is_superuser = True
            user.save()
            self.stdout.write('User "%s" granted superuser rights' % username)
        except User.DoesNotExist:
            self.stderr.write('User "%s" does not exist' % username)

==> lava-server_2016.12.orig.tar.gz: lava-server-2016.12/dashboard_app/management/commands/authorize_superuser.py <==
# Copyright (C) 2015 Linaro Limited
#
# Author: Senthil Kumaran S <senthil.kumaran@linaro.org>
#
# This file is part of LAVA Dashboard
#
# Lava Dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License version 3
# as published by the Free Software Foundation
#
# Lava Dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Lava Dashboard. If not, see <http://www.gnu.org/licenses/>.


import sys

from django.contrib.auth.models import User
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Authorize superuser.'

    def add_arguments(self, parser):
        parser.add_argument('--username', type=str,
                            help='Username to authorize.')

    def handle(self, *args, **options):
        username = options['username']
        if username is None:
            self.stderr.write("Username not specified.")
            sys.exit(2)

        try:
            user = User.objects.get(username=username)
            user.is_staff = True
            user.is_superuser = True
            user.save()
            self.stdout.write('User "%s" granted superuser rights' % username)
        except User.DoesNotExist:
            self.stderr.write('User "%s" does not exist' % username)
